@@ -16,8 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Based on Empathy's empathy-debug.
  */
@@ -31,8 +30,6 @@
 
 #include "nautilus-file.h"
 
-#ifdef ENABLE_DEBUG
-
 static DebugFlags flags = 0;
 static gboolean initialized = FALSE;
 
@@ -164,4 +161,3 @@ nautilus_debug_files (DebugFlags flag,
   va_end (args);
 }
 
-#endif /* ENABLE_DEBUG */
