@@ -41,7 +41,6 @@
 #include "nautilus-toolbar.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-list-view.h"
-#include "nautilus-view.h"
 
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
@@ -176,10 +175,6 @@ static const struct {
 	{ XF86XK_Stop,		"stop" },
 	{ XF86XK_Back,		"back" },
 	{ XF86XK_Forward,	"forward" },
-	/* View actions */
-	{ XF86XK_ZoomIn,	"zoom-in" },
-	{ XF86XK_ZoomOut,	"zoom-out" },
-
 #endif
 };
 
@@ -590,17 +585,17 @@ remember_focus_widget (NautilusWindow *window)
 	}
 }
 
-void
-nautilus_window_grab_focus (NautilusWindow *window)
+static void
+nautilus_window_grab_focus (GtkWidget *widget)
 {
 	NautilusWindowSlot *slot;
-	NautilusView *view;
 
-	slot = nautilus_window_get_active_slot (window);
-	view = nautilus_window_slot_get_view (slot);
+	slot = nautilus_window_get_active_slot (NAUTILUS_WINDOW (widget));
 
-	if (view) {
-		nautilus_view_grab_focus (view);
+        GTK_WIDGET_CLASS (nautilus_window_parent_class)->grab_focus (widget);
+
+	if (slot) {
+		gtk_widget_grab_focus (GTK_WIDGET (slot));
 	}
 }
 
@@ -608,12 +603,7 @@ static void
 restore_focus_widget (NautilusWindow *window)
 {
 	if (window->priv->last_focus_widget != NULL) {
-		if (NAUTILUS_IS_VIEW (window->priv->last_focus_widget)) {
-			nautilus_view_grab_focus (NAUTILUS_VIEW (window->priv->last_focus_widget));
-		} else {
-			gtk_widget_grab_focus (window->priv->last_focus_widget);
-		}
-
+		gtk_widget_grab_focus (window->priv->last_focus_widget);
 		unset_focus_widget (window);
 	}
 }
@@ -764,7 +754,7 @@ update_cursor (NautilusWindow *window)
                 GdkDisplay *display;
 
                 display = gtk_widget_get_display (GTK_WIDGET (window));
-		cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
+                cursor = gdk_cursor_new_from_name (display, "progress");
 		gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (window)), cursor);
 		g_object_unref (cursor);
 	} else {
@@ -942,12 +932,10 @@ nautilus_window_location_opened (NautilusWindow *window,
 
 /* Callback used when the places sidebar changes location; we need to change the displayed folder */
 static void
-places_sidebar_open_location_cb (GtkPlacesSidebar	*sidebar,
-				 GFile			*location,
-				 GtkPlacesOpenFlags	 open_flags,
-				 gpointer		 user_data)
+open_location_cb (NautilusWindow     *window,
+                  GFile              *location,
+                  GtkPlacesOpenFlags  open_flags)
 {
-	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
 	NautilusWindowOpenFlags flags;
 
 	switch (open_flags) {
@@ -985,17 +973,16 @@ places_sidebar_show_error_message_cb (GtkPlacesSidebar *sidebar,
 	eel_show_error_dialog (primary, secondary, GTK_WINDOW (window));
 }
 
-/* Callback used when the places sidebar needs us to present the Connect to Server dialog */
 static void
-places_sidebar_show_connect_to_server_cb (GtkPlacesSidebar *sidebar,
-					  gpointer          user_data)
+places_sidebar_show_other_locations (NautilusWindow   *window)
 {
-	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
-	NautilusApplication *application = NAUTILUS_APPLICATION (g_application_get_default ());
-	GtkWidget *dialog;
- 
-	dialog = nautilus_application_connect_server (application, window);
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+        GFile *location;
+
+        location = g_file_new_for_uri ("other-locations:///");
+
+        open_location_cb (window, location, GTK_PLACES_OPEN_NORMAL);
+
+        g_object_unref (location);
 }
 
 static GList *
@@ -1283,14 +1270,11 @@ nautilus_window_set_up_sidebar (NautilusWindow *window)
 					   (GTK_PLACES_OPEN_NORMAL
 					    | GTK_PLACES_OPEN_NEW_TAB
 					    | GTK_PLACES_OPEN_NEW_WINDOW));
-	gtk_places_sidebar_set_show_connect_to_server (GTK_PLACES_SIDEBAR (window->priv->places_sidebar), TRUE);
 
-	g_signal_connect (window->priv->places_sidebar, "open-location",
-			  G_CALLBACK (places_sidebar_open_location_cb), window);
+        g_signal_connect_swapped (window->priv->places_sidebar, "open-location",
+                                  G_CALLBACK (open_location_cb), window);
 	g_signal_connect (window->priv->places_sidebar, "show-error-message",
 			  G_CALLBACK (places_sidebar_show_error_message_cb), window);
-	g_signal_connect (window->priv->places_sidebar, "show-connect-to-server",
-			  G_CALLBACK (places_sidebar_show_connect_to_server_cb), window);
 	g_signal_connect (window->priv->places_sidebar, "drag-action-requested",
 			  G_CALLBACK (places_sidebar_drag_action_requested_cb), window);
 	g_signal_connect (window->priv->places_sidebar, "drag-action-ask",
@@ -1653,53 +1637,6 @@ path_bar_location_changed_callback (GtkWidget      *widget,
 	}
 }
 
-static gboolean
-path_bar_path_event_callback (NautilusPathBar *path_bar,
-			      GFile           *location,
-			      GdkEventButton  *event,
-			      NautilusWindow  *window)
-{
-	NautilusWindowSlot *slot;
-	NautilusWindowOpenFlags flags;
-	int mask;
-	NautilusView *view;
-	char *uri;
-
-	if (event->type == GDK_BUTTON_RELEASE) {
-		mask = event->state & gtk_accelerator_get_default_mod_mask ();
-		flags = 0;
-
-		if (event->button == 2 && mask == 0) {
-			flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-		} else if (event->button == 1 && mask == GDK_CONTROL_MASK) {
-			flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
-		}
-
-		if (flags != 0) {
-			slot = nautilus_window_get_active_slot (window);
-			nautilus_window_slot_open_location (slot, location, flags);
-		}
-
-		return FALSE;
-	}
-
-	if (event->button == 3) {
-		slot = nautilus_window_get_active_slot (window);
-		view = nautilus_window_slot_get_view (slot);
-		if (view != NULL) {
-			uri = g_file_get_uri (location);
-			nautilus_view_pop_up_pathbar_context_menu (view, event, uri);
-			g_free (uri);
-		}
-
-		return TRUE;
-	} else if (event->button == 2) {
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 static void
 notebook_popup_menu_new_tab_cb (GtkMenuItem *menuitem,
 				gpointer user_data)
@@ -1864,8 +1801,8 @@ setup_toolbar (NautilusWindow *window)
 
 	g_signal_connect_object (path_bar, "path-clicked",
 				 G_CALLBACK (path_bar_location_changed_callback), window, 0);
-	g_signal_connect_object (path_bar, "path-event",
-				 G_CALLBACK (path_bar_path_event_callback), window, 0);
+        g_signal_connect_swapped (path_bar, "open-location",
+                                  G_CALLBACK (open_location_cb), window);
 
 	/* connect to the location entry signals */
 	location_entry = nautilus_toolbar_get_location_entry (NAUTILUS_TOOLBAR (window->priv->toolbar));
@@ -2249,48 +2186,6 @@ nautilus_window_finalize (GObject *object)
 	G_OBJECT_CLASS (nautilus_window_parent_class)->finalize (object);
 }
 
-void
-nautilus_window_view_visible (NautilusWindow *window,
-			      NautilusView   *view)
-{
-	NautilusWindowSlot *slot;
-	GList *l;
-
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	/* FIXME: this code is odd and should not really be needed, but
-	 * removing it causes bugs, see e.g.
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=679640
-	 *
-	 * Needs more investigation...
-	 */
-	slot = nautilus_view_get_nautilus_window_slot (view);
-	if (g_object_get_data (G_OBJECT (slot), "nautilus-window-view-visible") != NULL) {
-		return;
-	}
-
-	g_object_set_data (G_OBJECT (slot), "nautilus-window-view-visible", GINT_TO_POINTER (1));
-
-	/* Look for other non-visible slots */
-	for (l = window->priv->slots; l != NULL; l = l->next) {
-		slot = l->data;
-		if (g_object_get_data (G_OBJECT (slot), "nautilus-window-view-visible") == NULL) {
-			return;
-		}
-	}
-
-	/* Look for other non-visible slots */
-	for (l = window->priv->slots; l != NULL; l = l->next) {
-		slot = l->data;
-		nautilus_window_slot_update_title (slot);
-	}
-
-	nautilus_window_grab_focus (window);
-
-	/* All slots, show window */
-	gtk_widget_show (GTK_WIDGET (window));
-}
-
 static void
 nautilus_window_save_geometry (NautilusWindow *window)
 {
@@ -2364,7 +2259,7 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 	/* make old slot inactive if it exists (may be NULL after init, for example) */
 	if (old_slot != NULL) {
 		/* inform slot & view */
-		g_signal_emit_by_name (old_slot, "inactive");
+		nautilus_window_slot_set_active (old_slot, FALSE);
 	}
 
 	window->priv->active_slot = new_slot;
@@ -2374,8 +2269,10 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 		/* inform sidebar panels */
                 nautilus_window_report_location_change (window);
 
+                nautilus_toolbar_set_active_slot (NAUTILUS_TOOLBAR (window->priv->toolbar), new_slot);
+
 		/* inform slot & view */
-                g_signal_emit_by_name (new_slot, "active");
+                nautilus_window_slot_set_active (new_slot, TRUE);
 	}
 }
 
@@ -2391,19 +2288,13 @@ nautilus_window_key_press_event (GtkWidget *widget,
 				 GdkEventKey *event)
 {
 	NautilusWindow *window;
-	NautilusWindowSlot *active_slot;
-	NautilusView *view;
 	GtkWidget *focus_widget;
 	int i;
 
 	window = NAUTILUS_WINDOW (widget);
 
-	active_slot = nautilus_window_get_active_slot (window);
-	view =  nautilus_window_slot_get_view (active_slot);
-
 	focus_widget = gtk_window_get_focus (GTK_WINDOW (window));
-	if (view != NULL && focus_widget != NULL &&
-	    GTK_IS_EDITABLE (focus_widget)) {
+        if (focus_widget != NULL && GTK_IS_EDITABLE (focus_widget)) {
 		/* if we have input focus on a GtkEditable (e.g. a GtkEntry), forward
 		 * the event to it before activating accelerator bindings too.
 		 */
@@ -2414,14 +2305,9 @@ nautilus_window_key_press_event (GtkWidget *widget,
 
 	for (i = 0; i < G_N_ELEMENTS (extra_window_keybindings); i++) {
 		if (extra_window_keybindings[i].keyval == event->keyval) {
-			const GActionGroup *action_group;
 			GAction *action;
 
 			action = g_action_map_lookup_action (G_ACTION_MAP (window), extra_window_keybindings[i].action);
-			if (action == NULL) {
-				action_group = nautilus_view_get_action_group (view);
-				action = g_action_map_lookup_action (G_ACTION_MAP (action_group), extra_window_keybindings[i].action);
-			}
 
 			g_assert (action != NULL);
 			if (g_action_get_enabled (action)) {
@@ -2623,6 +2509,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	wclass->window_state_event = nautilus_window_state_event;
 	wclass->button_press_event = nautilus_window_button_press_event;
 	wclass->delete_event = nautilus_window_delete_event;
+        wclass->grab_focus = nautilus_window_grab_focus;
 
 	class->close = real_window_close;
 
@@ -2643,6 +2530,8 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	gtk_widget_class_bind_template_child_private (wclass, NautilusWindow, notification_operation_open);
 	gtk_widget_class_bind_template_child_private (wclass, NautilusWindow, notification_operation_close);
 
+        gtk_widget_class_bind_template_callback (wclass, places_sidebar_show_other_locations);
+
 	properties[PROP_DISABLE_CHROME] =
 		g_param_spec_boolean ("disable-chrome",
 				      "Disable chrome",
