@@ -54,7 +54,7 @@ typedef gboolean (* NautilusWindowGoToCallback) (NautilusWindow *window,
                                                  GError *error,
                                                  gpointer user_data);
 
-#include "nautilus-view.h"
+#include "nautilus-files-view.h"
 #include "nautilus-window-slot.h"
 
 #define NAUTILUS_TYPE_WINDOW nautilus_window_get_type()
@@ -109,9 +109,6 @@ void             nautilus_window_close                (NautilusWindow    *window
 void             nautilus_window_go_to                (NautilusWindow    *window,
                                                        GFile             *location);
 void             nautilus_window_new_tab              (NautilusWindow    *window);
-
-void                 nautilus_window_view_visible          (NautilusWindow *window,
-                                                            NautilusView *view);
 NautilusWindowSlot * nautilus_window_get_active_slot       (NautilusWindow *window);
 void                 nautilus_window_set_active_slot       (NautilusWindow    *window,
                                                             NautilusWindowSlot *slot);
@@ -122,7 +119,6 @@ void                 nautilus_window_slot_close            (NautilusWindow *wind
                                                             NautilusWindowSlot *slot);
 
 void                 nautilus_window_sync_location_widgets (NautilusWindow *window);
-void                 nautilus_window_grab_focus            (NautilusWindow *window);
 
 void     nautilus_window_hide_sidebar         (NautilusWindow *window);
 void     nautilus_window_show_sidebar         (NautilusWindow *window);
